#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

import re
import ipaddress

from .common import gen_ip

def net2ip(net_str, _all=True, _error=True, strict=False):
    """
    拆分网段为IP
    :param net_str: 传入合法网段，eg: 192.168.1.0/24 or 192.168.1.1-33 or 192.168.1.5-192.168.1.8
    :param _all: 是否包含网络地址和广播地址 eg: False
    :param _error: 是否包含无法处理地址 eg: False
    :param strict: 是否校验网络地址 eg: False
    :return 返回list eg [ip1,ip2,...]
    """
    _list = []
    if re.search(r"^\d+\.\d+\.\d+\.\d+-\d+$", net_str):
        net, a, b = re.findall(r"(\d+\.\d+\.\d+\.)(\d+)-(\d+)", net_str)[0]
        _list += gen_ip("{}{}-{}{}".format(net, a, net, b))
    elif re.match(r"^\d+\.\d+\.\d+\.\d+-\d+\.\d+\.\d+\.\d+$", net_str):
        _list += gen_ip(net_str)
    else:
        try:
            if _all:
                _list.append(ipaddress.ip_network(
                    net_str, strict=strict).network_address.compressed)
            for ip in ipaddress.ip_network(net_str, strict=strict).hosts():
                _list.append(ip.compressed)
            if _all:
                _list.append(ipaddress.ip_network(
                    net_str, strict=strict).broadcast_address.compressed)
        except Exception:
            print("{} net_str error".format(net_str))
            if _error:
                _list.append(net_str)
    return _list
