#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

import re


def is_ip(value):
    ''' 
    判断是否是IP
    :param value eg: 127.0.0.1
    :return True or False
    '''
    pattern_ip = re.compile(
        r'^(1\d{2}|2[0-4]\d|25[0-5]|[1-9]\d|[1-9])\.(1\d{2}'
        r'|2[0-4]\d|25[0-5]|[1-9]\d|\d)\.(1\d{2}|2[0-4]\d'
        r'|25[0-5]|[1-9]\d|\d)\.(1\d{2}|2[0-4]\d|25[0-5]|[1-9]\d|\d)$'
    )
    return True if pattern_ip.match(value) else False


def get_ip(value):
    ''' 
    提取IP
    :param value eg: ss 127.0.0.1 d  
    :return True or False
    '''
    pattern_ip = re.compile(
        r'\b(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b')
    return pattern_ip.findall(value, re.S)


def get_ipv6(value):
    ''' 
    提取IP
    :param value eg: ss 127.0.0.1 d  
    :return True or False
    '''
    pattern_ip = re.compile(
        r'\b([0-9a-z]*:{1,4}){1,7}[0-9a-z]{1,4}\b')
    return pattern_ip.findall(value, re.S)


def is_domain(value):
    ''' 
    判断是否是域名
    :param value eg: baidu.com
    :return True or False
    '''
    pattern_domain = re.compile(
        r'^(([a-zA-Z]{1})|([a-zA-Z]{1}[a-zA-Z]{1})|'
        r'([a-zA-Z]{1}[0-9]{1})|([0-9]{1}[a-zA-Z]{1})|'
        r'([a-zA-Z0-9][-_.a-zA-Z0-9]{0,61}[a-zA-Z0-9]))\.'
        r'([a-zA-Z]{2,13}|[a-zA-Z0-9-]{2,30}.[a-zA-Z]{2,3})$'
    )
    return True if pattern_domain.match(value) else False


def rep_filename(_str):
    ''' 
    替换不能用于文件名的字符
    :param _str eg: 字符串
    '''
    return re.sub(r'[\/\\\:\*\?\"\<\>\|]', '', _str)


def rep_html(_str):
    ''' 
    替换html标签
    :param _str eg: 字符串
    '''
    return re.sub(r'<[^>]+>', '', _str)
